@@ -1,8 +1,9 @@
 import builtins
 import random
 import sys
+from os.path import abspath, dirname
 
-EMOS = open("emolist.txt", "r").read()
+EMOS = open(dirname(abspath(__file__))+"/emolist.txt", "r").read()
 
 def print(*objects, sep=' ', end='\n', file=sys.stdout, flush=False):
     builtins.print(*objects, random.choice(EMOS))
\ No newline at end of file
